Usage of Quizdrill

The current version of this file is availible at our wiki-page.

# Quizdrill/Usage

OpenFacts, the Open Source Knowledge Database

< Quizdrill

This page should give an overview of using Quizdrill. It is however still very incomplete.

## User interface

### Timer

Quizdrill is designed to, well drill you. It will ask you 15 questions after that it will minimize itself (giving you a break) and reappear after 15 min. If you don't have time than you can minimize the window again. After 5 min it will reappear again.

### Tabs

Depending on the type of quiz quizdrill shows up to four different tabs. The first tab is called "Words" and allows you to select which question (or categories of questions) should be asked (only in development version), as well as (if appropriate) which direction the questions should be asked (Screenshot).

The other three tabs are different ways of being tested. The first one is "Multiple Choice" (Screenshot). Here you have a selection of buttons with possible answers to press. On the second tab labeled "Simple Quiz" you answer the question by typing the answer in the given text field (Screenshot). After pressing the "Evaluate"-button (or the return-key) your answer gets evaluated. Note that quizdrill isn't very forgiving: you have to type the exact answer (extra spaces at the beginning and end are fine, but that's about it).

### Status bar

After a question is completed the status bar shows the given (correct) answer.

## Strategies

When starting to memorize it is a good idea to start with the multiple choice quiz. Once you can recognize the words the simple quiz offer a non-frustrating next-step. If you have difficulties typing the flash card might be the better alternative. When you get stuck in the simple quiz (spell error or you simple forgot the word) peaking at the multiple choice and then typing it into the simple quiz is often a good idea.